@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-1998 Janne Lf <jlof@mail.student.oulu.fi>
+ * Copyright (C) 1997-1998 Janne Löf <jlof@mail.student.oulu.fi>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -16,10 +16,12 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include "config.h"
+
+#include <stdarg.h>
+
 #include "gdkgl.h"
 #include "gtkglarea.h"
-#include <GL/gl.h>
-#include <stdarg.h>
 
 static void gtk_gl_area_class_init    (GtkGLAreaClass *klass);
 static void gtk_gl_area_init          (GtkGLArea      *glarea);
@@ -47,7 +49,7 @@ gtk_gl_area_get_type (void)
         0,              /* n_preallocs */
         (GInstanceInitFunc) gtk_gl_area_init,
       };
-      
+
       object_type = g_type_register_static (GTK_TYPE_DRAWING_AREA,
                                             "GtkGLArea",
                                             &object_info, 0);
@@ -62,7 +64,7 @@ gtk_gl_area_class_init (GtkGLAreaClass *klass)
 
   parent_class = g_type_class_peek_parent(klass);
   object_class = (GtkObjectClass*) klass;
-  
+
   object_class->destroy = gtk_gl_area_destroy;
 }
 
@@ -97,7 +99,7 @@ gtk_gl_area_new_vargs(GtkGLArea *share, ...)
   while ( (attrlist[i] = va_arg(ap, int)) != GDK_GL_NONE) /* copy args to list */
     i++;
   va_end(ap);
-  
+
   glarea = gtk_gl_area_share_new(attrlist, share);
 
   g_free(attrlist);
@@ -114,48 +116,39 @@ gtk_gl_area_new (int *attrlist)
 GtkWidget*
 gtk_gl_area_share_new (int *attrlist, GtkGLArea *share)
 {
-
-#if !defined(WIN32)
-
-  GdkVisual *visual;
   GdkGLContext *glcontext;
   GtkGLArea *gl_area;
+#if defined GDK_WINDOWING_X11
+  GdkVisual *visual;
+#endif
 
   g_return_val_if_fail(share == NULL || GTK_IS_GL_AREA(share), NULL);
 
+#if defined GDK_WINDOWING_X11
   visual = gdk_gl_choose_visual(attrlist);
   if (visual == NULL)
     return NULL;
 
   glcontext = gdk_gl_context_share_new(visual, share ? share->glcontext : NULL, TRUE);
+#else
+  glcontext = gdk_gl_context_attrlist_share_new(attrlist, share ? share->glcontext : NULL, TRUE);
+#endif
   if (glcontext == NULL)
     return NULL;
 
+#if defined GDK_WINDOWING_X11
   /* use colormap and visual suitable for OpenGL rendering */
   gtk_widget_push_colormap(gdk_colormap_new(visual,TRUE));
   gtk_widget_push_visual(visual);
-  
+#endif
+
   gl_area = g_object_new(GTK_TYPE_GL_AREA, NULL);
   gl_area->glcontext = glcontext;
 
+#if defined GDK_WINDOWING_X11
   /* pop back defaults */
   gtk_widget_pop_visual();
   gtk_widget_pop_colormap();
-
-#else
-
-  GdkGLContext *glcontext;
-  GtkGLArea *gl_area;
-
-  g_return_val_if_fail(share == NULL || GTK_IS_GL_AREA(share), NULL);
-
-  glcontext = gdk_gl_context_attrlist_share_new(attrlist, share ? share->glcontext : NULL, TRUE);
-  if (glcontext == NULL)
-    return NULL;
-
-  gl_area = g_object_new(GTK_TYPE_GL_AREA, NULL);
-  gl_area->glcontext = glcontext;
-
 #endif
 
   return GTK_WIDGET(gl_area);
@@ -169,7 +162,7 @@ gtk_gl_area_destroy(GtkObject *object)
 
   g_return_if_fail (object != NULL);
   g_return_if_fail (GTK_IS_GL_AREA(object));
-  
+
   gl_area = GTK_GL_AREA(object);
 
   if (gl_area->glcontext)
